==> pmml-model-1.6.11-sources.jar: org/dmg/pmml/support_vector_machine/SupportVector.java <==

package org.dmg.pmml.support_vector_machine;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.MissingAttributeException;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "SupportVector", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("SupportVector")
@JsonPropertyOrder({
    "vectorId",
    "extensions"
})
public class SupportVector
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<SupportVector>
{

    @XmlAttribute(name = "vectorId", required = true)
    @JsonProperty("vectorId")
    private String vectorId;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371272L;

    public SupportVector() {
    }

    @ValueConstructor
    public SupportVector(
        @org.jpmml.model.annotations.Property("vectorId")
        String vectorId) {
        this.vectorId = vectorId;
    }

    public String requireVectorId() {
        if (this.vectorId == null) {
            throw new MissingAttributeException(this, PMMLAttributes.SUPPORTVECTOR_VECTORID);
        }
        return this.vectorId;
    }

    public String getVectorId() {
        return vectorId;
    }

    public SupportVector setVectorId(
        @org.jpmml.model.annotations.Property("vectorId")
        String vectorId) {
        this.vectorId = vectorId;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public SupportVector addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.7.2-sources.jar: org/dmg/pmml/support_vector_machine/SupportVector.java <==

package org.dmg.pmml.support_vector_machine;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.MissingAttributeException;
import org.jpmml.model.annotations.CollectionElementType;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "SupportVector", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("SupportVector")
@JsonPropertyOrder({
    "vectorId",
    "extensions"
})
public class SupportVector
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<SupportVector>
{

    @XmlAttribute(name = "vectorId", required = true)
    @JsonProperty("vectorId")
    private String vectorId;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    @CollectionElementType(Extension.class)
    private List<Extension> extensions;
    private static final long serialVersionUID = 67371272L;

    public SupportVector() {
    }

    @ValueConstructor
    public SupportVector(
        @org.jpmml.model.annotations.Property("vectorId")
        String vectorId) {
        this.vectorId = vectorId;
    }

    public String requireVectorId() {
        if (this.vectorId == null) {
            throw new MissingAttributeException(this, PMMLAttributes.SUPPORTVECTOR_VECTORID);
        }
        return this.vectorId;
    }

    public String getVectorId() {
        return vectorId;
    }

    public SupportVector setVectorId(
        @org.jpmml.model.annotations.Property("vectorId")
        String vectorId) {
        this.vectorId = vectorId;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<>();
        }
        return this.extensions;
    }

    @Override
    public SupportVector addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
